ffmpeg: ffmpeg video converter
==============================

Description
-----------

ffmpeg is a very fast video and audio converter that can also grab from a live
audio/video source. It can also convert between arbitrary sample rates and
resize video on the fly with a high quality polyphase filter.

License
-------

"FFmpeg is licensed under the GNU Lesser General Public License (LGPL) version
2.1 or later. However, FFmpeg incorporates several optional parts and
optimizations that are covered by the GNU General Public License (GPL) version
2 or later. If those parts get used the GPL applies to all of FFmpeg."

http://ffmpeg.org/legal.html

Upstream Contact
----------------

http://ffmpeg.org/

